Enum CustomCursorSource
pub enum CustomCursorSource {
Image(CursorImage),
Animation(CursorAnimation),
Url {
hotspot_x: u16,
hotspot_y: u16,
url: String,
},
}Expand description
Source for CustomCursor.
See CustomCursor for more details.
Variants
Image(CursorImage)
Cursor that is backed by RGBA image.
See CustomCursorSource::from_rgba for more.
Platform-specific
- iOS / Android / Orbital: Unsupported
Animation(CursorAnimation)
Animated cursor.
See CustomCursorSource::from_animation for more.
Platform-specific
- iOS / Android / Wayland / Windows / X11 / macOS / Orbital: Unsupported
Url
Creates a new cursor from a URL pointing to an image. It uses the url css function, but browser support for image formats is inconsistent. Using PNG is recommended.
Platform-specific
- iOS / Android / Wayland / Windows / X11 / macOS / Orbital: Unsupported
Implementations
impl CustomCursorSource
impl CustomCursorSource
pub fn from_rgba(
rgba: Vec<u8>,
width: u16,
height: u16,
hotspot_x: u16,
hotspot_y: u16,
) -> Result<CustomCursorSource, BadImage>
pub fn from_rgba( rgba: Vec<u8>, width: u16, height: u16, hotspot_x: u16, hotspot_y: u16, ) -> Result<CustomCursorSource, BadImage>
Creates a new cursor from an rgba buffer.
The alpha channel is assumed to be not premultiplied.
pub fn from_animation(
duration: Duration,
cursors: Vec<CustomCursor>,
) -> Result<CustomCursorSource, BadAnimation>
pub fn from_animation( duration: Duration, cursors: Vec<CustomCursor>, ) -> Result<CustomCursorSource, BadAnimation>
Crates a new animated cursor from multiple CustomCursors
Supplied cursors can’t be empty or other animations.