Struct CustomCursor
pub struct CustomCursor(pub Arc<dyn CustomCursorProvider>);Expand description
Use a custom image as a cursor (mouse pointer).
Is guaranteed to be cheap to clone.
Platform-specific
Web: Some browsers have limits on cursor sizes usually at 128x128.
Example
use winit_core::cursor::CustomCursorSource;
let w = 10;
let h = 10;
let rgba = vec![255; (w * h * 4) as usize];
#[cfg(not(target_family = "wasm"))]
let source = CustomCursorSource::from_rgba(rgba, w, h, w / 2, h / 2).unwrap();
#[cfg(target_family = "wasm")]
let source = CustomCursorSource::Url {
url: String::from("http://localhost:3000/cursor.png"),
hotspot_x: 0,
hotspot_y: 0,
};
if let Ok(custom_cursor) = event_loop.create_custom_cursor(source) {
window.set_cursor(custom_cursor.clone().into());
}Tuple Fields
0: Arc<dyn CustomCursorProvider>Methods from Deref<Target = dyn CustomCursorProvider>
pub fn cast_ref<T>(&self) -> Option<&T>where
T: CustomCursorProvider,
pub fn cast_ref<T>(&self) -> Option<&T>where
T: CustomCursorProvider,
Downcast to the backend concrete type.
Returns None if the object was not from that backend.