CustomCursorProvider

Trait CustomCursorProvider 

pub trait CustomCursorProvider:
    AsAny
    + Debug
    + Send
    + Sync {
    // Required method
    fn is_animated(&self) -> bool;
}

Required Methods

fn is_animated(&self) -> bool

Whether a cursor was backed by animation.

Implementations



impl dyn CustomCursorProvider + '_

pub fn cast_ref<T>(&self) -> Option<&T>

Downcast to the backend concrete type.

Returns None if the object was not from that backend.

pub fn cast_mut<T>(&mut self) -> Option<&mut T>

Mutable downcast to the backend concrete type.

Returns None if the object was not from that backend.

pub fn cast<T>( self: Box<dyn CustomCursorProvider + '_>, ) -> Result<Box<T>, Box<dyn CustomCursorProvider + '_>>

Owned downcast to the backend concrete type.

Returns Err with self if the object was not from that backend.

Implementors