Trait CustomCursorProvider
pub trait CustomCursorProvider:
AsAny
+ Debug
+ Send
+ Sync {
// Required method
fn is_animated(&self) -> bool;
}Required Methods
fn is_animated(&self) -> bool
fn is_animated(&self) -> bool
Whether a cursor was backed by animation.
Implementations
impl dyn CustomCursorProvider + '_
impl dyn CustomCursorProvider + '_
pub fn cast_ref<T>(&self) -> Option<&T>where
T: CustomCursorProvider,
pub fn cast_ref<T>(&self) -> Option<&T>where
T: CustomCursorProvider,
Downcast to the backend concrete type.
Returns None if the object was not from that backend.
pub fn cast_mut<T>(&mut self) -> Option<&mut T>where
T: CustomCursorProvider,
pub fn cast_mut<T>(&mut self) -> Option<&mut T>where
T: CustomCursorProvider,
Mutable downcast to the backend concrete type.
Returns None if the object was not from that backend.
pub fn cast<T>(
self: Box<dyn CustomCursorProvider + '_>,
) -> Result<Box<T>, Box<dyn CustomCursorProvider + '_>>where
T: CustomCursorProvider,
pub fn cast<T>(
self: Box<dyn CustomCursorProvider + '_>,
) -> Result<Box<T>, Box<dyn CustomCursorProvider + '_>>where
T: CustomCursorProvider,
Owned downcast to the backend concrete type.
Returns Err with self if the object was not from that backend.